@@ -9,7 +9,6 @@ from threading import Thread
 import requests.exceptions
 
 import bond.proto
-from bond.commands.base_command import BaseCommand
 from bond.database import BondDatabase, DB_DIRNAME
 
 Q = Queue()
@@ -58,14 +57,16 @@ def wait_upload(timeout=None):
     return Q.get(timeout=timeout)
 
 
-class BackupCommand(BaseCommand):
+class BackupCommand(object):
     subcmd = "backup"
     help = """Backup a Bond"""
-    arguments = {}
+    arguments = {
+        "--bond-id": {"help": "ignore selected Bond and use provided"},
+    }
 
     def run(self, args):
         start_daemon(4444)
-        bondid = BondDatabase.get_assert_selected_bondid()
+        bondid = args.bond_id or BondDatabase.get_assert_selected_bondid()
         timestamp = str(int(time.time()))
         body = {
             "backup": 1,
@@ -77,14 +78,14 @@ class BackupCommand(BaseCommand):
         print(rsp)
         if rsp["s"] != 200:
             raise Exception(
-                "Error HTTP %d starting backup: %s", rsp["s"], rsp["b"]["_error_msg"]
+                f"Error HTTP {rsp['s']} starting backup: {rsp['b']['_error_msg']}"
             )
         time.time()
         while True:
             time.sleep(1)
             rsp = bond.proto.get(bondid, topic="sys/backup")
             if rsp["b"]["backup"] == -1:
-                raise Exception("Backup error: %s" % rsp["b"]["error_msg"])
+                raise Exception(f"Backup error: {rsp['b']['error_msg']}")
             if rsp["b"]["backup"] == 2:
                 print("Bond reports backup success.")
                 break
@@ -114,7 +115,7 @@ def get_file_list():
     return rv
 
 
-class RestoreCommand(BaseCommand):
+class RestoreCommand(object):
     subcmd = "restore"
     help = """Restore a Bond."""
     arguments = {
@@ -133,6 +134,7 @@ class RestoreCommand(BaseCommand):
             "help": "Only for test purposes. May cause unexpected behavior.",
             "action": "store_true",
         },
+        "--bond-id": {"help": "ignore selected Bond and use provided"},
     }
 
     def run(self, args):  # noqa: C901
@@ -141,7 +143,7 @@ class RestoreCommand(BaseCommand):
             if len(file_list) == 0:
                 print("No backups found")
             else:
-                print("Found %d backups: " % len(file_list))
+                print(f"Found {len(file_list)} backups:")
                 for f in get_file_list():
                     print("  " + f["datestr"] + "   " + f["file"])
             return
@@ -153,7 +155,7 @@ class RestoreCommand(BaseCommand):
             args.file = file_list[-1]["file"]
 
         start_daemon(4444)
-        bondid = BondDatabase.get_assert_selected_bondid()
+        bondid = args.bond_id or BondDatabase.get_assert_selected_bondid()
         # timestamp = str(int(time.time()))
         body = {
             "restore": 1,
@@ -165,14 +167,14 @@ class RestoreCommand(BaseCommand):
         print(rsp)
         if rsp["s"] != 200:
             raise Exception(
-                "Error HTTP %d starting restore: %s", rsp["s"], rsp["b"]["_error_msg"]
+                f"Error HTTP {rsp['s']} starting restore: {rsp['b']['_error_msg']}"
             )
         time.time()
         while True:
             time.sleep(1)
             rsp = bond.proto.get(bondid, topic="sys/backup")
             if rsp["b"]["restore"] == -1:
-                raise Exception("Restore error: %s" % rsp["b"]["error_msg"])
+                raise Exception(f"Restore error: {rsp['b']['error_msg']}")
             if rsp["b"]["restore"] == 2:
                 print("Bond reports restore success!")
                 break
@@ -184,8 +186,3 @@ class RestoreCommand(BaseCommand):
             bond.proto.put(bondid, topic="sys/reboot")
         except requests.exceptions.ReadTimeout:
             pass
-
-
-def register():
-    BackupCommand()
-    RestoreCommand()
