@@ -1,11 +1,10 @@
 import time
 
 from bond.cli.table import Table
-from bond.commands.base_command import BaseCommand
 from bond.proto.mdns import Scanner
 
 
-class DiscoverCommand(BaseCommand):
+class DiscoverCommand(object):
     subcmd = "discover"
     help = "Discover Bonds on local network."
     arguments = {
@@ -16,10 +15,6 @@ class DiscoverCommand(BaseCommand):
         table = Table(["bondid", "ip", "port"], quiet=args.q)
         scanner = Scanner(table.add_row)  # noqa: F841
         try:
-            time.sleep(5)
+            time.sleep(10)
         except KeyboardInterrupt:
             pass
-
-
-def register():
-    DiscoverCommand()
