@@ -1,9 +1,8 @@
 from bond.cli.table import Table
-from bond.commands.base_command import BaseCommand
 from bond.database import BondDatabase
 
 
-class ListCommand(BaseCommand):
+class BondListCommand(object):
     subcmd = "list"
     help = "List Bonds in local database."
     arguments = {
@@ -18,12 +17,18 @@ class ListCommand(BaseCommand):
         else:
             table = Table(["bondid", "ip", "token"], quiet=args.q)
             bonds = BondDatabase.get_bonds()
+            selected_bond = BondDatabase().get("selected_bondid")
             for bondid in bonds.keys():
                 b = bonds[bondid]
+                bond_id_display = (
+                    bondid + " <-----"
+                    if not args.q and bondid == selected_bond
+                    else bondid
+                )
                 table.add_row(
-                    {"bondid": bondid, "ip": b.get("ip"), "token": b.get("token")}
+                    {
+                        "bondid": bond_id_display,
+                        "ip": b.get("ip"),
+                        "token": b.get("token"),
+                    }
                 )
-
-
-def register():
-    ListCommand()
