@@ -1,9 +1,8 @@
-from bond.commands.base_command import BaseCommand
 from bond.commands.token import check_unlocked_token
 from bond.database import BondDatabase
 
 
-class SelectCommand(BaseCommand):
+class SelectCommand(object):
     subcmd = "select"
     help = """Select a single Bond to interact with,
               If the token of this Bond is unlocked, it will be set.
@@ -29,9 +28,8 @@ class SelectCommand(BaseCommand):
             ]
             if len(matches) == 0:
                 proceed = input(
-                    "%s hasn't been discovered by bond-cli ('bond discover')."
-                    "Proceed with setting it? It may not be reachable. y/N"
-                    % args.bond_id
+                    f"{args.bond_id} hasn't been discovered by bond-cli ('bond discover').\n"
+                    "Proceed with setting it? It may not be reachable. [y/N] "
                 )
                 if proceed.lower() == "y":
                     bond_id = args.bond_id
@@ -49,18 +47,14 @@ class SelectCommand(BaseCommand):
             BondDatabase.set("selected_bondid", bond_id)
             if args.ip:
                 BondDatabase.set_bond(bond_id, "ip", args.ip)
-                print("Set %s IP %s" % (bond_id, args.ip))
+                print(f"Set {bond_id} IP {args.ip}")
             if args.port:
                 BondDatabase.set_bond(bond_id, "port", args.port)
-                print("Set %s port %s" % (bond_id, args.ip))
-            print("Selected Bond: %s" % BondDatabase().get("selected_bondid"))
+                print(f"Set {bond_id} port {args.ip}")
+            print(f"Selected Bond: {BondDatabase().get('selected_bondid')}")
             token = check_unlocked_token()  # noqa: F841
         elif args.clear:
             BondDatabase().pop("selected_bondid", None)
             print("Cleared selected Bond")
         else:
-            print("Bond selected: " + BondDatabase().get_assert_selected_bondid())
-
-
-def register():
-    SelectCommand()
+            print(f"Bond selected: {BondDatabase().get_assert_selected_bondid()}")
