@@ -1,11 +1,10 @@
 from base64 import b64encode
 
 import bond.proto
-from bond.commands.base_command import BaseCommand
 from bond.database import BondDatabase
 
 
-class WifiCommand(BaseCommand):
+class WifiCommand(object):
     subcmd = "wifi"
     help = "Connect to WiFi"
     arguments = {
@@ -14,10 +13,11 @@ class WifiCommand(BaseCommand):
             "required": True,
         },
         "--password": {"help": "The password", "required": True},
+        "--bond-id": {"help": "ignore selected Bond and use provided"},
     }
 
     def run(self, args):
-        bondid = BondDatabase.get_assert_selected_bondid()
+        bondid = args.bond_id or BondDatabase.get_assert_selected_bondid()
         rsp = bond.proto.put(
             bondid,
             topic="sys/wifi/sta",
@@ -27,25 +27,22 @@ class WifiCommand(BaseCommand):
             },
         )
         if rsp["s"] > 299:
-            print("HTTP %d %s" % (rsp["s"], rsp["b"]["_error_msg"]))
+            print(f"HTTP {rsp['s']} {rsp['b']['_error_msg']}")
 
 
-class WifiShutdownCommand(BaseCommand):
+class WifiShutdownCommand(object):
     subcmd = "wifi_shutdown"
     help = "Shutdown WiFi until reboot (requires fw >= v2.11.4)"
-    arguments = {}
+    arguments = {
+        "--bond-id": {"help": "ignore selected Bond and use provided"},
+    }
 
     def run(self, args):
-        bondid = BondDatabase.get_assert_selected_bondid()
+        bondid = args.bond_id or BondDatabase.get_assert_selected_bondid()
         rsp = bond.proto.patch(
             bondid,
             topic="debug/wifi",
             body={"shutdown": 1},
         )
         if rsp["s"] > 299:
-            print("HTTP %d %s" % (rsp["s"], rsp["b"]["_error_msg"]))
-
-
-def register():
-    WifiCommand()
-    WifiShutdownCommand()
+            print(f"HTTP {rsp['s']} {rsp['b']['_error_msg']}")
